import setuptools

setuptools.setup(
    name="streamlit-markmap",
    version="1.0.1",
    author="echoopen",
    author_email="632019805@qq.com",
    description="markmap",
    long_description="",
    long_description_content_type="text/plain",
    url="",
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[],
    python_requires=">=3.6",
    install_requires=[
        "streamlit >= 0.63",
    ],
)
